pub struct UnipolarBrushCell {
pub v: f64,
pub persistent: f64,
pub v_rest: f64,
pub v_reset: f64,
pub v_threshold: f64,
pub tau_m: f64,
pub tau_persistent: f64,
pub persistent_gain: f64,
pub gain: f64,
pub dt: f64,
}Expand description
Cerebellar unipolar brush cell (UBC) — excitatory interneuron in vestibular cerebellum.
Biophysics: LIF with a slow persistent (NMDA-like) current that sustains depolarisation long after input ceases. The single brush-like dendrite forms a giant synapse with a mossy fibre rosette, creating a 1:1 relay that amplifies and prolongs the input signal.
UBCs are unique excitatory interneurons in the granular layer. They transform brief mossy fibre bursts into prolonged granule cell activation, important for vestibular signal processing and timing.
Bhatt et al., J Comp Neurol 349:560, 1994; Diana et al., J Neurosci 27:4374, 2007.
Fields
v: f64persistent: f64v_rest: f64v_reset: f64v_threshold: f64tau_m: f64tau_persistent: f64persistent_gain: f64gain: f64dt: f64Implementations